import QtQuick 1.1
import ".."

ModalDialog {
    id: root
    dismissable: true

    property string networkId: networkIdPicker.lumpValue()
    property string frequency: frequencyPicker.lumpValue()
    property string modulation: modulationForWscan(modPicker.lumpValue())
    property string symbolRate: symbolratePicker.lumpValue()

    function modulationForWscan() {
        // Translate into a form to be used by wscan "initial tuning data"
        switch (modPicker.lumpValue()) {
            case "64 QAM":
                return "QAM64"
            case "128 QAM":
                return "QAM128"
            case "256 QAM":
                return "QAM256"
        }
        return "QAMUNKNOWN"
    }

    onDismissed: {
        networkIdPicker.currentIndex = 0
        frequencyPicker.currentIndex = 0
        modPicker.currentIndex = 0
        symbolratePicker.currentIndex = 0
        root.hide()
    }

    Connections {
        target: root.visible ? keymapper : null
        onEnter2Pressed: {
            console.log("enter2Pressed", "AddNetworkDialog")
            root.dismissed()
        }
    }

    BorderImage {   // pop-up dialog background
        id: border2

        x: 332
        y: 21
        width: 800
        height: 730
        source: "../graphics/Pop_Up_Lrg_Grey.png"
        border { top: 152; bottom: 165; left: 145; right: 144 }
        ImageButton {
            id: close_button2
            visible: main.isTouch

            z: 200

            width: 36
            height: 36
            anchors {   right: parent.right ; rightMargin: 100 ;
                top: parent.top ; topMargin: 40
            }
            upimage: "Keypad/KeyPad_X_Large.png"
            downimage: "Keypad/KeyPad_X_Large.png"

            onClicked: root.dismissed()
            mouseAreaScale: 2.0

        }
        Text {
            id: scanHeader
            width: 501
            height: 99
            color: "#ffffff"
            text: qsTr("Network Scan") + application.emptyString
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 35
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.pixelSize: 40
        }

        ListView {
            id: scanControls
            anchors {
                top: scanHeader.bottom
                topMargin: -20
                horizontalCenter: parent.horizontalCenter
            }
            width: 430
            height: 700
            spacing: 5
            z: 100
            model: controlList.model
            snapMode: ListView.SnapToItem
            interactive: false
            highlightRangeMode: ListView.ApplyRange
            preferredHighlightBegin: height/2 - 30
            preferredHighlightEnd: height/2 + 30
            highlightMoveSpeed: 10000
            currentIndex: controlList.curIndex
            onVisibleChanged: if (visible) controlList.curIndex = 0
            highlight: Component {
                BorderImage {
                    id: selectionCursor
                    visible: main.isTft && controlList.listening
                    border { left: 70; top: 5; bottom: 5; right: 70 }
                    source: "../graphics/tft/maintenance_menus_cursor2.png"
                    width: scanControls.currentItem ? scanControls.currentItem.navCursorWidth : 0
                    height: 71
                    horizontalTileMode: BorderImage.Stretch
                }
            }
        }
        KeyedControlList {
            id: controlList
            listening: false
            listView: scanControls
            width: scanControls.width
            curIndex: 0
            edgeBehavior: "wrap"

            Row {
                id: networkIdRow
                property bool selected: false

                width: parent.width
                height: 100
                spacing: 10
                Text {
                    text: qsTr("Network ID") + application.emptyString
                    width: 100
                    height: 50
                    anchors.verticalCenter: parent.verticalCenter
                }
                Item {
                    // Spacer
                    height: 50
                    width: 40
                }

                ValuePickerRow {
                    id: networkIdPicker
                    onExitedLeft: { }
                    onExitedRight: { controlList.nextIndex() }
                    listenKeys: networkIdRow.selected
                    numberOfItems: 5
                    height: 100
                    width: 260
                    anchors.verticalCenter: parent.verticalCenter
                    delegate: Component {
                        NumberPicker {
                            id: picker
                            listenKeys: picker.ListView.isCurrentItem && networkIdPicker.listenKeys
                            minValue: 0
                            maxValue: 9
                            defaultValue: 0
                            valueWraps: true
                            font { pixelSize: 24; bold: true }
                            columnSpacing: 5
                            upImage: "graphics/tft/arrow_up.png"
                            upImagePressed: upImage
                            downImage: "graphics/tft/arrow_down.png"
                            downImagePressed: downImage
                            width:50
                            height:90
                            showArrows: main.isTouch || listenKeys
                        }
                    }
                }
            }
            Row {
                id: frequencyRow
                property bool selected: false
                width: parent.width
                height: 100
                spacing: 10
                Text {
                    text: qsTr("Frequency") + application.emptyString
                    width: 100
                    height: 50
                    anchors.verticalCenter: parent.verticalCenter
                }
                Item {
                    // Spacer
                    height: 50
                    width: 40
                }
                ValuePickerRow {
                    id: frequencyPicker
                    listenKeys: frequencyRow.selected
                    onExitedLeft: { controlList.prevIndex() }
                    onExitedRight: { controlList.nextIndex() }
                    numberOfItems: 6
                    height: 100
                    width: 310
                    anchors.verticalCenter: parent.verticalCenter
                    delegate: Component {
                        NumberPicker {
                            id: picker
                            listenKeys: picker.ListView.isCurrentItem && frequencyPicker.listenKeys
                            minValue: 0
                            maxValue: 9
                            defaultValue: 0
                            valueWraps: true
                            font { pixelSize: 24; bold: true }
                            columnSpacing: 5
                            upImage: "graphics/tft/arrow_up.png"
                            upImagePressed: upImage
                            downImage: "graphics/tft/arrow_down.png"
                            downImagePressed: downImage
                            width:50
                            height:90
                            showArrows: main.isTouch || listenKeys
                        }
                    }
                }
                Text {
                    text: "KHz"
                    width: 100
                    height: 50
                    anchors.verticalCenter: parent.verticalCenter
                }
            }
            Row {
                id: modulationRow
                property bool selected: false
                width: parent.width
                height: 100
                spacing: 10
                Text {
                    text: qsTr("Modulation") + application.emptyString
                    width: 100
                    height: 50
                    anchors.verticalCenter: parent.verticalCenter
                }
                Item {
                    // Spacer
                    height: 50
                    width: 40
                }
                Item {
                    id: centeringRow
                    width: 300
                    height: 100
                    anchors.verticalCenter: parent.verticalCenter
                    ValuePickerRow {
                        id: modPicker
                        listenKeys: modulationRow.selected
                        onExitedLeft: { controlList.prevIndex() }
                        onExitedRight: { controlList.nextIndex() }
                        numberOfItems: 1
                        height: 100
                        width: 100
                        anchors.centerIn: parent
                        delegate: Component {
                            NumberPicker {
                                id: picker
                                listenKeys: picker.ListView.isCurrentItem && modPicker.listenKeys
                                ListModel {
                                    id: qamModel
                                    ListElement { label: "64 QAM"; value: 64 }
                                    ListElement { label: "128 QAM"; value: 128 }
                                    ListElement { label: "256 QAM"; value: 256 }
                                }
                                minValue: 0
                                maxValue: qamModel.count - 1
                                printedValue: qamModel.get(value).label
                                defaultValue: 0
                                valueWraps: true
                                font { pixelSize: 24; bold: true }
                                columnSpacing: 5
                                upImage: "graphics/tft/arrow_up.png"
                                upImagePressed: upImage
                                downImage: "graphics/tft/arrow_down.png"
                                downImagePressed: downImage
                                width:100
                                height:90
                                showArrows: main.isTouch || listenKeys
                            }
                        }
                    }
                }

            }
            Row {
                id: symbolrateRow
                property bool selected: false
                width: parent.width
                height: 100
                spacing: 10
                Text {
                    text: qsTr("Symbol Rate") + application.emptyString
                    width: 100
                    height: 50
                    anchors.verticalCenter: parent.verticalCenter
                }
                Item {
                    // Spacer
                    height: 50
                    width: 40
                }
                ValuePickerRow {
                    id: symbolratePicker
                    listenKeys: symbolrateRow.selected
                    onExitedLeft: { controlList.prevIndex() }
                    onExitedRight: { }
                    numberOfItems: 4
                    height: 100
                    width: 210
                    anchors.verticalCenter: parent.verticalCenter
                    delegate: Component {
                        NumberPicker {
                            id: picker
                            listenKeys: picker.ListView.isCurrentItem && symbolratePicker.listenKeys
                            minValue: 0
                            maxValue: 9
                            defaultValue: 0
                            valueWraps: true
                            font { pixelSize: 24; bold: true }
                            columnSpacing: 5
                            upImage: "graphics/tft/arrow_up.png"
                            upImagePressed: upImage
                            downImage: "graphics/tft/arrow_down.png"
                            downImagePressed: downImage
                            width:50
                            height:90
                            showArrows: main.isTouch || listenKeys
                        }
                    }
                }
                Text {
                    text: "KS/s"
                    width: 100
                    height: 50
                    anchors.verticalCenter: parent.verticalCenter
                }
            }
        }
        ImageButton {
            id: okButton

            visible: main.isTouch
            anchors {
                top: scanControls.bottom
                topMargin: -260
                horizontalCenter: parent.horizontalCenter
            }
            label: qsTr("OK") + application.emptyString
            label_color: "black"
            label_under: true
            label_y_offset: 4
            upimage: "graphics/205/Lrg_Button_Up.png"
            downimage: "graphics/205/Lrg_Button_Down.png"

            onClicked: {
                root.dismissed()
            }
        }
        Text {
            visible: main.isTft
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 60
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: -10
            color: "#ffffff"
            font { bold: true; pixelSize: 24 }
            text: qsTr("press ENTER to continue") + application.emptyString
        }
    }
    Component.onCompleted: hide()
}
