import QtQuick 1.1
import ConfigurationData 1.0
import Brainboard 1.0
import ".."
Item{
    id: root
    anchors.fill: parent
    state: brainboard.detectedMachineTypeString

    property int fontSize: 24
    property int topOffset: 80
    property int itemSpacing: 5
    property int itemColumnSpacing: 50
    property int currentSelectedIndex
    property bool isSetupWizard: false

    signal declineTogglePressed()
    signal screenExited()

    onDeclineTogglePressed: saveButton.visible = main.isTouch && !root.isSetupWizard

    Component.onCompleted: {
        nucleus.getOptions()
    }

    Connections {
        target: nucleus
        onTreadmillSetInclineOptionCompleted: {
            if(result === true) {
                setOptionComplete.show()
            }
        }
    }

    Connections {
        target: main.isTft && root.visible
                && ((!isSetupWizard && main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0)
                    || (isSetupWizard && main.state === "SetupWizardState")) ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsSetup")
            root.screenExited()
        }

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsSetup")
            if (!isSetupWizard) diagnostics_screen.item.unselectScreen()
        }
    }

    ListModel {
        id: productListModel

        ListElement {
            name: "TES900"
            imageName: "../graphics/product_images/2013/TRU_TES900_sideview.png"
        }
        ListElement {
            name: "TCS400"
            imageName: "../graphics/product_images/2013/TRU_TCS400_sideview.png"
        }
        ListElement {
            name: "TCS600"
            imageName: "../graphics/product_images/2013/TRU_TCS600_sideview.png"
        }
        ListElement {
            name: "TCS650"
            imageName: "../graphics/product_images/2013/TRU_TCS650_sideview.png"
        }
        ListElement {
            name: "TCS650"
            imageName: "../graphics/product_images/2013/TRU_TCS650_sideview.png"
        }
        ListElement {
            name: "TCS900"
            imageName: "../graphics/product_images/2013/TRU_TCS900_sideview.png"
        }
        ListElement {
            name: "TCS900"
            imageName: "../graphics/product_images/2013/TRU_TCS900_sideview.png"
        }
        ListElement {
            name: "TPS825"
            imageName: "../graphics/product_images/2013/TRU_TES900_sideview.png"
        }
        ListElement {
            name: "XCS400"
            imageName: "../graphics/product_images/2013/TRU_XCS400_sideview.png"
        }
        ListElement {
            name: "XCS900"
            imageName: "../graphics/product_images/2013/TRU_XCS900_sideview.png"
        }
        ListElement {
            name: "TS1000"
            imageName: "../graphics/product_images/2015/TRU_TS1000_sideview.png"
        }
        ListElement {
            name: "RCS400"
            imageName: "../graphics/product_images/2013/TRU_RCS400_sideview.png"
        }
        ListElement {
            name: "UCS400"
            imageName: "../graphics/product_images/2013/TRU_UCS400_sideview.png"
        }
        ListElement {
            name: "UCS900"
            imageName: "../graphics/product_images/2013/TRU_UCS900_sideview.png"
        }
        ListElement {
            name: "RCS900"
            imageName: "../graphics/product_images/2013/TRU_RCS900_sideview.png"
        }
        ListElement {
            name: "TL1000"
            imageName: "../graphics/product_images/2015/TRU_TL1000_sideview.png"
        }
        ListElement {
            name: "TI1000"
            imageName: "../graphics/product_images/2016/TRU_TI1000_sideview.png"
        }
    }

    Text {
        id: currentConfigurationText
        text: qsTr("Current Machine Configuration")+application.emptyString
        font.pixelSize: 36
        font.bold: true
        font.underline: true
        anchors.top: parent.top
        anchors.topMargin: 20
        anchors.horizontalCenter: parent.horizontalCenter
    }
    Text {
        id: currentProductConfigurationText
        text: machineinfo.modelString + " " + qsTr(machineinfo.productTypeString) + application.emptyString
        font.pixelSize: 36
        font.bold: true
        anchors.top: currentConfigurationText.bottom
        anchors.topMargin: 10
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Item {

        id: machineConfigurationArea
        width: 400

        anchors {
            top: currentProductConfigurationText.bottom
            topMargin: 25
            right: parent.horizontalCenter
            rightMargin: 25
            bottom: parent.bottom
            bottomMargin: 50
        }

        Column {
            spacing: 5
            width: parent.width
            Text {
                font.pixelSize: 28
                text: "Max. Speed: " + (machineinfo.treadmillSpeedMaxMph / 10).toFixed(1) + "MPH"
            }

            Text {
                font.pixelSize: 28
                text: "Max. Incline: " + (machineinfo.treadmillInclineMaxPercentGrade / 10).toFixed(1) + "%"
            }

            Text {
                font.pixelSize: 28
                text: "Min. Incline: " + (machineinfo.treadmillInclineMinPercentGrade / 10).toFixed(1) + "%"
            }

            Row {
                visible: nucleus.declineOption
                width: parent.width
                spacing: 50
                Text {
                    id: declineToggleLabel
                    font.pixelSize: 28
                    text: machineinfo.treadmillInclineMinPercentGrade < 0 ? "Set Non-Decline" : "Set Decline"
                }

                ImageButton{
                    id: declineToggleButton
                    useParentContainerSize: true
                    width: 50
                    height: 50
                    upimage:"graphics/200/TRU_200_other_small_Button_Up.png"
                    downimage:"graphics/200/TRU_200_other_small_Button_Down.png"
                    label_under: false
                    label_y_offset: -3
                    anchors.verticalCenter: declineToggleLabel.verticalCenter
                    onClicked: machineinfo.treadmillInclineMinPercentGrade < 0 ? nucleus.treadmillSetNonDeclineOption() : nucleus.treadmillSetDeclineOption()
                    visible: true
                }
            }
        }
    }

    function getImageElementFromModelString(modelStr)
    {
        var i
        for(i = 0; i < productListModel.count; i++) {
            var item = productListModel.get(i)
            if(item.name === modelStr) {
                return item.imageName;
            }
        }
        return "";
    }

    Item {
        id: productImageArea
        width: height
        height: parent.width * 0.25
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: parent.width / 4
        anchors.top: machineConfigurationArea.top

        Image{
            id:productImage
            anchors.fill: parent
            smooth: true
            source: getImageElementFromModelString(machineinfo.modelString)
        }
    }

    MessagePopup {   // pop-up dialog background
        id: setOptionComplete
        message: qsTr("Power Cycle Required.")
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && root.isSetupWizard

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to continue") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
