import QtQuick 1.1
import Process 0.1
import "Diagnostics"

ModalDialog {
    id: root

    property string preparingString: qsTr("Preparing Diagnostic Report...") + application.emptyString
    property string sendingString: qsTr("Sending Diagnostic Report...") + application.emptyString

    isTop: true
    isTransparent: false
    dismissable: false
    Component.onCompleted: if (!application.crashRecovery) hide()

    function start() {
        // Note: Check connection list directly to avoid having to wait on
        // NetworkConnections object to build its list
        var files = storageMgr.listFiles("/etc/network/interfaces.d", "*.cfg")
        if (!options.diagnosticsUploadEnabled || files.length <= 0) {
            // Feature disabled or no network configured - we are done
            root.hide()
            main.restartRequired = true
            return
        }

        autoLogUploader.start()
    }

    BorderImage {   // pop-up dialog background
        x: 332
        y: 161
        width: 800
        height: 390
        source: "./graphics/Pop_Up_Lrg_Grey.png"
        border { top: 152; bottom: 165; left: 145; right: 144 }
        Text {
            width: 501
            color: "#ffffff"
            text: autoLogUploader.running ? root.sendingString : root.preparingString
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.pixelSize: 50
        }
    }

    LogUploader {
        id: autoLogUploader

        onProcessFinished: {
            root.hide()
            main.restartRequired = true
        }

        onUploadFailed: {
            logger.logAlways("Automatic Log Upload: Upload Failed")
        }

        onTransferComplete: {
            logger.logAlways("Automatic Log Upload: Transfer Complete")
        }

        onTerminated: {
        }

        onConnectionError: {
            logger.logAlways("Automatic Log Upload: Connection Error")
        }
    }
}
