import QtQuick 1.1
import "Globals.js" as Globals

Item {
    id: root

    property bool unlocked: false
    property int currentSpeed
    property int currentIncline

    signal speedChange(real speed)
    signal inclineChange(int incline)

    state: unlocked ? "unlocked" : "locked"
    height: 62
    width: childrenRect.width
    // list of quick speeds
    ListModel {
        id: speeds
        ListElement { speed: 3 }
        ListElement { speed: 4 }
        ListElement { speed: 6 }
        ListElement { speed: 7 }
        ListElement { speed: 8 }
    }

    ListModel {
        id: km_speeds
        ListElement { speed: 5 }
        ListElement { speed: 7 }
        ListElement { speed: 9 }
        ListElement { speed: 11 }
        ListElement { speed: 13 }
    }

    // list of quick inclines
    ListModel {
        id: inclines
        ListElement { incline: 0 }
        ListElement { incline: 3 }
        ListElement { incline: 5 }
        ListElement { incline: 7 }
        ListElement { incline: 9 }
    }

    Row {
        Text {
            id: unlockText

            visible: !root.unlocked
            font.pointSize: 14
            font.bold: true
            text: qsTr("UNLOCK QUICK KEYS") + application.emptyString
            width: 250
            wrapMode: Text.WordWrap
            verticalAlignment: Text.AlignVCenter
            anchors.verticalCenter: parent.verticalCenter
        }

        Item {
            id: buttons

            width: buttons_row.width
            height: buttons_row.height

            SliderControl {
                id: slider

                z:30
                minValue: 0
                maxValue: 100
                clickableTrack: false
                anchors.fill: parent; anchors.leftMargin: 35 ; anchors.rightMargin: 35
                showButtons: false
                showValue: false
                thumbImage: (Qt.application.layoutDirection === Qt.RightToLeft) ? "graphics/224/224_Data_ToolBar_Slider_Arrow_Left.png" : "graphics/224/224_Data_ToolBar_Slider_Arrow.png"
                trackImage: "graphics/224/Unlock_Quick_Keys_Gradiant.png"
                trackImageOpacity: 0.6
                thumbMouseAreaScale: 1.3
                onReleased: {
                    if(value > 65) {
                        root.unlocked = true
                        value = 0
                    }
                    else
                        sliderSnap.start()
                }
                NumberAnimation on value { id: sliderSnap ; to: 0;  duration: 200; easing.type: Easing.Linear }
            }

            Row {
                id: buttons_row
                //visible: root.unlocked
                spacing: 15

                ImageButton {
                    id: incline
                    toggle: true
                    visible: root.unlocked
                    icon:"graphics/netpulse/WORKLOAD-INCLINE_icon_GRAY.png"
                    upimage: "graphics/224/224_ToolBar_Square_Disabled.png"
                    downimage: "graphics/224/224_ToolBar_Square_Down.png"
                    radioGroup: [ incline, speed ]
                }

                ImageButton {
                    id: speed
                    toggle: true
                    visible: root.unlocked
                    icon:"graphics/netpulse/PACE-SPEED_icon_GRAY.png"
                    upimage: "graphics/224/224_ToolBar_Square_Disabled.png"
                    downimage: "graphics/224/224_ToolBar_Square_Down.png"
                    radioGroup: [ incline, speed ]
                }

                Row {
                    id: speed_buttons

                    spacing: 15
                    visible: root.visible && speed.isDown
                    Repeater {
                        model: workoutScreen.unitState === "METRIC" ? km_speeds : speeds
                        delegate: ImageButton {
                            label: "<style> \
                                   p.small {line-height:normal; font-size:10px;} \
                                   p.big {line-height:30%; font-size:40px ; vertical-align:text-top;} \
                                   </style>" +
                            "<center>" + "<p class='big'>" + speed + "<br>" + "</p><p class='small'>" + (workoutScreen.unitState === "METRIC" ? "KPH" : "MPH") + "</p></center>"
                            label_color: "black"
                            upimage: currentSpeed === (workoutScreen.unitState === "METRIC" ? Globals.kmToMile(speed).toFixed(1) : speed)*10 ? "graphics/224/224_ToolBar_Square_Down.png" : "graphics/224/224_ToolBar_Square_Disabled.png"
                            downimage: "graphics/224/224_ToolBar_Square_Down.png"
                            onClicked: root.speedChange(workoutScreen.unitState === "METRIC" ? Globals.kmToMile(speed).toFixed(1) : speed)
                            enabled: root.unlocked
                        } // speed ImageButton delegate
                    } // end Repeater
                } // speeds

                Row {
                    id: incline_buttons

                    spacing: 15
                    visible: incline.isDown

                    Repeater {
                        model: inclines
                        delegate: ImageButton {
                            label: "<style> \
                                   p.small {line-height:normal; font-size:10px;} \
                                   p.big {line-height:30%; font-size:40px ; vertical-align:text-top;} \
                                   </style>" +
                            "<center>" + "<p class='big'>" + incline + "<br>" + "</p><p class='small'>" + "%</p></center>"
                            label_color: "black"
                            upimage: currentIncline === incline*10 ? "graphics/224/224_ToolBar_Square_Down.png" : "graphics/224/224_ToolBar_Square_Disabled.png"
                            downimage: "graphics/224/224_ToolBar_Square_Down.png"
                            onClicked: root.inclineChange(incline)
                            enabled: root.unlocked
                        } // end ImageButton delegate
                    } // end Repeater
                } // inclines
            } // end buttons_row
        } // end Item buttons
    } // end Row

    states: [
        State {
            name: "locked"
            PropertyChanges { target: slider ; opacity: 1.0 }
            PropertyChanges { target: speed ; isDown: true }
        },
        State {
            name: "unlocked"
            PropertyChanges { target: slider ; opacity: 0 }
            PropertyChanges { target: speed ; isDown: true }
        }
    ]
}
