import QtQuick 1.1
import ".."
import WorkoutManager 1.0
import WorkoutRunData 1.0
import "../Globals.js" as Globals

Item {
    id: root

    property bool isMountEverest: workoutProgram.programIndex === WorkoutProgram.MOUNT_EVEREST_PROG
    property bool isKilimanjaro: workoutProgram.programIndex === WorkoutProgram.MOUNT_KILIMANJARO_PROG
    property bool isMountRainier: workoutProgram.programIndex === WorkoutProgram.MOUNT_RAINIER_PROG
    property bool isGatewayArch: workoutProgram.programIndex === WorkoutProgram.GATEWAY_ARCH_PROG
    property bool isEiffelTower: workoutProgram.programIndex === WorkoutProgram.EIFFEL_TOWER_PROG
    property int baselineY: root.height - (isGatewayArch ? 75 : 42)
    property int topMarginY: isGatewayArch || isEiffelTower ? 4 : 10
    property int currentUserElevation: workoutProgram.startElevation + aWorkoutRunData.workoutFeetClimbed
    property int endElevation: workoutProgram.endElevation
    property string climbTimeRemaining: Globals.secondsToMSString(aWorkoutRunData.climbTimeRemaining)
    property string projectedFinishTime: workoutManager.treadIncline > 0 ? Globals.secondsToMSString(aWorkoutRunData.projectedFinishTime) : "--:--"
    property variant images: getPreloadImages()
    property string backgroundImage: images[0]

    width: 1000
    height: 406

    Connections {
        target: currentViewName === "MONUMENT_VIEW" && visible && opacity > 0 ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "MonumentViewContainer")
        }
    }

    Rectangle {
        id: shadowRect
        visible: isGatewayArch || isEiffelTower
        x: 0
        y: 0
        width: root.width
        height: progressLine.y
        clip: true
        Image {
            id: shadowImage
            width: bgImage.width
            height: bgImage.height
            source: parent.visible && images.length > 1 ? images[1] : ""
        }
    }

    Image {
        id: bgImage
        anchors.fill: parent
        source: root.backgroundImage
        z: -1 //Ensure that this is displayed below clipped region
    }

    Text {
        id: projectedFinishTime
        visible: aWorkoutRunData.mode === WorkoutRunData.WORKOUT_MODE
        text: qsTr("PROJECTED FINISH TIME") + application.emptyString
        anchors.left: parent.left
        anchors.top: parent.top
        anchors.leftMargin: 10
        anchors.topMargin: 10
        font.pixelSize: 17
        font.bold: true
    }

    Text {
        id: projectedFtVal
        visible: aWorkoutRunData.mode === WorkoutRunData.WORKOUT_MODE
        text: root.projectedFinishTime
        anchors.left: parent.left
        anchors.leftMargin: 10
        anchors.top: projectedFinishTime.bottom
        anchors.topMargin: -2
        font.pixelSize: 48
        font.bold: true
    }

    Rectangle {
        id: progressLine
        color: "#eb1f28"
        y: root.baselineY - Math.round((root.baselineY - root.topMarginY) * (root.currentUserElevation / root.endElevation))
        width: 400
        height: 10
        radius: 5
        x: {
            switch (workoutProgram.programIndex) {
                case WorkoutProgram.GATEWAY_ARCH_PROG:
                    return 287
                case WorkoutProgram.EIFFEL_TOWER_PROG:
                    return 295
                default:
                    return 388
            }
        }
    }

    Text {
        id: currentElevationText
        text: application.formatWithSeparator(workoutScreen.unitState === "METRIC" ? Globals.feetToMeters(root.currentUserElevation).toFixed(0) : root.currentUserElevation) + " " + (workoutScreen.unitState === "METRIC" ? qsTr("Meters") : qsTr("FT")) + application.emptyString
        color: "black"
        font.pixelSize: 22
        font.bold: true
        anchors.verticalCenter: progressLine.verticalCenter
        anchors.verticalCenterOffset: 2
        anchors.left: progressLine.right
        anchors.leftMargin: 3
    }

    function getPreloadImages() {
        switch (workoutProgram.programIndex) {
            case WorkoutProgram.MOUNT_EVEREST_PROG:
                return ["../graphics/TI1000/Monuments/alpine_everest_withpath.png"]
            case WorkoutProgram.MOUNT_RAINIER_PROG:
                return ["../graphics/TI1000/Monuments/alpine_rainier_withpath.png"]
            case WorkoutProgram.MOUNT_KILIMANJARO_PROG:
                return ["../graphics/TI1000/Monuments/alpine_kilimanjaro_withpath.png"]
            case WorkoutProgram.EIFFEL_TOWER_PROG:
                return ["../graphics/TI1000/Monuments/alpine_eiffel_full.png", "../graphics/TI1000/Monuments/alpine_eiffel_empty.png"]
            case WorkoutProgram.GATEWAY_ARCH_PROG:
                return ["../graphics/TI1000/Monuments/alpine_arch_full.png", "../graphics/TI1000/Monuments/alpine_arch_empty.png"]
        }
        return []
    }

// NOTE: Platform readings are not currently used, but are kept for reference or later use
//    ListModel {
//        id: mtEverestTextItems
//        ListElement { x: 485; y: 271; label: "BASE CAMP"; elevFeet: 17000; elevMeters: 5182 }
//        ListElement { x: 600; y: 224; label: '"Lho La"'; elevFeet: 19900; elevMeters: 6066 }
//        ListElement { x: 695; y: 183; label: "Camp 2"; elevFeet: 21300; elevMeters: 6492 }
//        ListElement { x: 725; y: 129; label: "Geneva Spur"; elevFeet: 24500; elevMeters: 7468 }
//        ListElement { x: 693; y: 71; label: "Camp 4"; elevFeet: 26000; elevMeters: 7925 }
//        ListElement { x: 598; y: 19; label: "SUMMIT"; elevFeet: 29029; elevMeters: 8848 }
//    }

//    ListModel {
//        id: mtRainierTextItems
//        ListElement { x: 590; y: 230; label: "Alta Vista"; elevFeet: 5440; elevMeters: 1658 }
//        ListElement { x: 748; y: 107; label: "Camp Muir"; elevFeet: 10188; elevMeters: 3105 }
//        ListElement { x: 665; y: 45; label: "Disappointment Cleaver"; elevFeet: 11600; elevMeters: 3536 }
//        ListElement { x: 544; y: 3; label: "Colombia Crest Summit"; elevFeet: 14411; elevMeters: 4392 }
//    }

//    ListModel {
//        id: kilimanjaroTextItems
//        ListElement { x: 514; y: 232; label: "Machame Gate"; elevFeet: 5905; elevMeters: 1800 }
//        ListElement { x: 665; y: 142; label: "Shira Peak"; elevFeet: 13000; elevMeters: 3962 }
//        ListElement { x: 592; y: 90; label: "Lava Tower Camp"; elevFeet: 15174; elevMeters: 4625 }
//        ListElement { x: 550; y: 49; label: "Mawenzi Peak"; elevFeet: 16893; elevMeters: 5149 }
//        ListElement { x: 482; y: 0; label: "Uhuru Peak"; elevFeet: 19341; elevMeters: 5895 }
//    }

//    ListModel {
//        id: eiffelTowerPlatforms
//        ListElement { height: 187; label: QT_TR_NOOP("FIRST PLATFORM") }
//        ListElement { height: 377; label: QT_TR_NOOP("SECOND PLATFORM") }
//        ListElement { height: 906; label: QT_TR_NOOP("THIRD PLATFORM") }
//        ListElement { height: 1063; label: QT_TR_NOOP("OFFICIAL HEIGHT") }
//    }
}
